[jboss-cvs] JBossAS SVN: r94388 - in projects/ejb3/trunk/metadata-spi: src/main/java/org/jboss/ejb3/metadata/spi/javaee and 1 other directory.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Mon Oct 5 15:25:29 EDT 2009


Author: jaikiran
Date: 2009-10-05 15:25:29 -0400 (Mon, 05 Oct 2009)
New Revision: 94388

Added:
   projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionType.java
Removed:
   projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/TransactionType.java
Modified:
   projects/ejb3/trunk/metadata-spi/pom.xml
   projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/MessageDrivenBeanMetaData.java
   projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionBeanMetaData.java
Log:
EJBTHREE-1791 More spi changes and JDK1.6 enforcement in the metadata-spi pom

Modified: projects/ejb3/trunk/metadata-spi/pom.xml
===================================================================
--- projects/ejb3/trunk/metadata-spi/pom.xml	2009-10-05 18:21:24 UTC (rev 94387)
+++ projects/ejb3/trunk/metadata-spi/pom.xml	2009-10-05 19:25:29 UTC (rev 94388)
@@ -17,8 +17,33 @@
   <description>
     JBoss EJB3 Metadata SPI - provides the neccessary metadata support for EJB3 components
   </description>
+  
   <build>
-  <!--  <plugins>
+   
+    <plugins>
+        
+        <!--  Enforce JDK6 -->
+        <plugin>
+            <artifactId>maven-enforcer-plugin</artifactId>
+            <executions>
+              <execution>
+                <id>enforce-jdk6</id>
+                <goals>
+                  <goal>enforce</goal>
+                </goals>
+                <configuration>
+                  <rules>
+                    <requireJavaVersion>
+                        <version>1.6</version>
+                    </requireJavaVersion> 
+                  </rules>
+                </configuration>
+              </execution>
+            </executions>
+        </plugin>
+        
+  </plugins>
+  <!--
     <plugin>
       <groupId>org.codehaus.mojo</groupId>
       <artifactId>jaxb2-maven-plugin</artifactId>
@@ -35,8 +60,8 @@
 	<schemaFiles>ejb-jar_3_0.xsd</schemaFiles>
 	<packageName>org.jboss.ejb3.metadata.spi</packageName>
       </configuration>
-    </plugin>
-    </plugins> -->
+    </plugin> -->
+    
   </build>
   
 
@@ -58,6 +83,13 @@
     	<version>2.1</version>
     </dependency>
 
+    <!-- for javax.ejb.* -->
+    <dependency>
+        <groupId>org.jboss.ejb3</groupId>
+        <artifactId>jboss-ejb3-api</artifactId>
+        <version>3.1.0-SNAPSHOT</version>
+    </dependency>
+    
     <!--  for javax.persistence.* -->
     <dependency>
         <groupId>org.hibernate</groupId>

Modified: projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/MessageDrivenBeanMetaData.java
===================================================================
--- projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionBeanMetaData.java	2009-10-05 18:21:24 UTC (rev 94387)
+++ projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionBeanMetaData.java	2009-10-05 19:25:29 UTC (rev 94388)
@@ -24,6 +24,8 @@
 import java.util.List;
 import java.util.Set;
 
+import javax.ejb.TransactionManagementType;
+
 /**
  *
  * Represents metadata for a session bean
@@ -279,15 +281,17 @@
 
 
    /**
-    * TODO: Revisit this - do we need this
+    * @return Returns the session bean type
     */
-   String getSessionType();
+   SessionType getSessionType();
 
    /**
-    * TODO: Revisit this - do we need this
+    * Sets the session type of this bean
+    * 
+    * @param sessionType
     *
     */
-   void setSessionType(String value);
+   void setSessionType(SessionType sessionType);
 
    /**
     * Returns the timeout method of this bean.
@@ -371,7 +375,7 @@
     * Returns the transaction type of this bean
     *
     */
-   TransactionType getTransactionType();
+   TransactionManagementType getTransactionType();
 
    /**
     * Sets the transaction type of this bean
@@ -379,7 +383,7 @@
     * @param transactionType The transaction type of this bean
     *
     */
-   void setTransactionType(TransactionType transactionType);
+   void setTransactionType(TransactionManagementType transactionType);
 
    /**
     * Returns a list of around-invoke metadata of this bean.

Added: projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionType.java
===================================================================
--- projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionType.java	                        (rev 0)
+++ projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionType.java	2009-10-05 19:25:29 UTC (rev 94388)
@@ -0,0 +1,36 @@
+/*
+* JBoss, Home of Professional Open Source
+* Copyright 2005, JBoss Inc., and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+package org.jboss.ejb3.metadata.spi.javaee;
+
+/**
+ * SessionType
+ * 
+ * Represents the session type of a bean
+ * 
+ * @author Jaikiran Pai
+ * @version $Revision: $
+ */
+public enum SessionType 
+{
+   STATELESS,
+   STATEFUL
+}

Deleted: projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/TransactionType.java
===================================================================
--- projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/TransactionType.java	2009-10-05 18:21:24 UTC (rev 94387)
+++ projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/TransactionType.java	2009-10-05 19:25:29 UTC (rev 94388)
@@ -1,47 +0,0 @@
-/*
-* JBoss, Home of Professional Open Source
-* Copyright 2005, JBoss Inc., and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-package org.jboss.ejb3.metadata.spi.javaee;
-
-/**
- * TransactionType
- *
- * Represents the different possible transaction
- * types for a bean
- *
- * @author Jaikiran Pai
- * @version $Revision: $
- */
-public enum TransactionType
-{
-
-   /**
-    * Represents container managed transaction
-    * type for a bean
-    */
-   CONTAINER_MANAGED_TRANSACTION_TYPE,
-
-   /**
-    * Represents bean managed transaction type for a bean
-    */
-   BEAN_MANAGED_TRANSACTION_TYPE;
-
-}




More information about the jboss-cvs-commits mailing list
--- projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/MessageDrivenBeanMetaData.java	2009-10-05 18:21:24 UTC (rev 94387)
+++ projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/MessageDrivenBeanMetaData.java	2009-10-05 19:25:29 UTC (rev 94388)
@@ -9,6 +9,8 @@
 
 import java.util.List;
 
+import javax.ejb.TransactionManagementType;
+
 /**
  *
  *
@@ -130,18 +132,18 @@
    void setTimeoutMethod(NamedMethodMetaData timeoutMethod);
 
    /**
     * Returns the transaction type of this bean
     *
     */
-   TransactionType getTransactionType();
+   TransactionManagementType getTransactionType();
 
    /**
     * Sets the transaction type of this bean
     *
     * @param transactionType The transaction type of this bean
     *
     */
-   void setTransactionType(TransactionType transactionType);
+   void setTransactionType(TransactionManagementType transactionType);
 
    /**
     *
@@ -130,18 +132,18 @@
 
    /**
-    * Returns the transaction type of this bean
+    * Returns the transaction management type of this bean
     *
     */
@@ -130,18 +132,18 @@
 
    /**
-    * Sets the transaction type of this bean
+    * Sets the transaction management type of this bean
     *
@@ -130,18 +132,18 @@
     *
-    * @param transactionType The transaction type of this bean
+    * @param transactionType The transaction management type of this bean
     *
     */

Modified: projects/ejb3/trunk/metadata-spi/src/main/java/org/jboss/ejb3/metadata/spi/javaee/SessionBeanMetaData.java
===================================================================